Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(164)

Unified Diff: third_party/WebKit/Source/core/dom/CrossThreadTask.h

Issue 2104913002: Rename threadSafeBind() to crossThreadBind() (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@TRV_CTCPointer
Patch Set: Rebase Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/dom/CrossThreadTask.h
diff --git a/third_party/WebKit/Source/core/dom/CrossThreadTask.h b/third_party/WebKit/Source/core/dom/CrossThreadTask.h
index c64682a114de9947c02a99161d64c32a685c9a1d..fcaca1fc69282a3e8b7490b71f428a618dd14d3f 100644
--- a/third_party/WebKit/Source/core/dom/CrossThreadTask.h
+++ b/third_party/WebKit/Source/core/dom/CrossThreadTask.h
@@ -33,13 +33,13 @@
#include "core/dom/ExecutionContext.h"
#include "core/dom/ExecutionContextTask.h"
-#include "platform/ThreadSafeFunctional.h"
+#include "platform/CrossThreadFunctional.h"
#include <type_traits>
namespace blink {
// createCrossThreadTask(...) is ExecutionContextTask version of
-// threadSafeBind().
+// crossThreadBind().
// Using WTF::bind() directly is not thread-safe due to temporary objects, see
// https://crbug.com/390851 for details.
//
@@ -75,8 +75,8 @@ namespace blink {
// ExecutionContext:
// |context| is supplied by the target thread.
//
// Deep copies by threadSafeBind():
// |ptr|, |p1|, ..., |pn| are processed by threadSafeBind() and thus
// CrossThreadCopier.
// You don't have to call manually e.g. isolatedCopy().
// To pass things that cannot be copied by CrossThreadCopier
@@ -85,7 +85,7 @@ namespace blink {
template<typename FunctionType, typename... P>
std::unique_ptr<ExecutionContextTask> createCrossThreadTask(FunctionType function, P&&... parameters)
{
- return internal::createCallClosureTask(threadSafeBind(function, std::forward<P>(parameters)...));
+ return internal::createCallClosureTask(crossThreadBind(function, std::forward<P>(parameters)...));
}
} // namespace blink
« no previous file with comments | « third_party/WebKit/Source/core/dom/CompositorProxy.cpp ('k') | third_party/WebKit/Source/core/dom/MainThreadTaskRunner.cpp » ('j') | no next file with comments »
@@ -75,8 +75,8 @@ namespace blink {
// |context| is supplied by the target thread.
//
-// Deep copies by threadSafeBind():
-// |ptr|, |p1|, ..., |pn| are processed by threadSafeBind() and thus
+// Deep copies by crossThreadBind():
+// |ptr|, |p1|, ..., |pn| are processed by crossThreadBind() and thus
// CrossThreadCopier.
// You don't have to call manually e.g. isolatedCopy().

Powered by Google App Engine
This is Rietveld 408576698